==> open-xchange-messaging-rss_6.16.1.0.orig.tar.gz: open-xchange-messaging-rss-6.16.1.0/src/com/openexchange/messaging/rss/RSSMessagingService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messaging.rss;

import java.util.Collections;
import java.util.List;
import com.openexchange.datatypes.genericonf.DynamicFormDescription;
import com.openexchange.datatypes.genericonf.FormElement;
import com.openexchange.messaging.MessagingAccountAccess;
import com.openexchange.messaging.MessagingAccountManager;
import com.openexchange.messaging.MessagingAccountTransport;
import com.openexchange.messaging.MessagingAction;
import com.openexchange.messaging.MessagingException;
import com.openexchange.messaging.MessagingService;
import com.openexchange.messaging.generic.DefaultMessagingAccountManager;
import com.openexchange.session.Session;
import com.sun.syndication.fetcher.FeedFetcher;
import com.sun.syndication.fetcher.impl.HashMapFeedInfoCache;
import com.sun.syndication.fetcher.impl.HttpURLFeedFetcher;


/**
 * {@link RSSMessagingService}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class RSSMessagingService implements MessagingService {

    private static final String DISPLAY_NAME = "RSS Feed";
    private static final DynamicFormDescription FORM_DESCRIPTION = new DynamicFormDescription();
    public static final String ID = "com.openexchange.messaging.rss";
    static {
        FORM_DESCRIPTION.add(FormElement.input("url", "URL"));
    }
    
    private final MessagingAccountManager accountManager = new DefaultMessagingAccountManager(ID);
    private FeedFetcher fetcher = new HttpURLFeedFetcher(HashMapFeedInfoCache.getInstance());

    
    public MessagingAccountAccess getAccountAccess(int accountId, Session session) throws MessagingException {
        return new RSSFeedOperations(accountId, session, fetcher, accountManager);
    }

    public MessagingAccountManager getAccountManager() {
        return accountManager;
    }

    public MessagingAccountTransport getAccountTransport(int accountId, Session session) throws MessagingException {
        return new RSSFeedOperations(accountId, session, fetcher, accountManager);
    }

    public String getDisplayName() {
        return DISPLAY_NAME;
    }

    public DynamicFormDescription getFormDescription() {
        return FORM_DESCRIPTION;
    }

    public String getId() {
        return ID;
    }

    public List<MessagingAction> getMessageActions() {
        return Collections.emptyList();
    }

    public static String buildFolderId(int accountId, String folder) {
        StringBuilder stringBuilder = new StringBuilder(ID);
        stringBuilder.append("://").append(accountId).append('/').append(folder);
        return stringBuilder.toString();
    }

}

==> open-xchange-messaging-rss_6.18.0.0.orig.tar.gz: open-xchange-messaging-rss-6.18.0.0/src/com/openexchange/messaging/rss/RSSMessagingService.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.messaging.rss;

import java.util.Collections;
import java.util.List;
import com.openexchange.datatypes.genericonf.DynamicFormDescription;
import com.openexchange.datatypes.genericonf.FormElement;
import com.openexchange.messaging.MessagingAccountAccess;
import com.openexchange.messaging.MessagingAccountManager;
import com.openexchange.messaging.MessagingAccountTransport;
import com.openexchange.messaging.MessagingAction;
import com.openexchange.messaging.MessagingException;
import com.openexchange.messaging.MessagingService;
import com.openexchange.messaging.generic.DefaultMessagingAccountManager;
import com.openexchange.session.Session;
import com.sun.syndication.fetcher.FeedFetcher;
import com.sun.syndication.fetcher.impl.HashMapFeedInfoCache;
import com.sun.syndication.fetcher.impl.HttpURLFeedFetcher;

/**
 * {@link RSSMessagingService}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class RSSMessagingService implements MessagingService {

    private static final String DISPLAY_NAME = "RSS Feed";
    private static final DynamicFormDescription FORM_DESCRIPTION = new DynamicFormDescription();
    public static final String ID = "com.openexchange.messaging.rss";
    static {
        FORM_DESCRIPTION.add(FormElement.input("url", FormStrings.FORM_LABEL_URL));
    }
    
    private final MessagingAccountManager accountManager = new DefaultMessagingAccountManager(ID);
    private FeedFetcher fetcher = new HttpURLFeedFetcher(HashMapFeedInfoCache.getInstance());

    
    public MessagingAccountAccess getAccountAccess(int accountId, Session session) throws MessagingException {
        return new RSSFeedOperations(accountId, session, fetcher, accountManager);
    }

    public MessagingAccountManager getAccountManager() {
        return accountManager;
    }

    public MessagingAccountTransport getAccountTransport(int accountId, Session session) throws MessagingException {
        return new RSSFeedOperations(accountId, session, fetcher, accountManager);
    }

    public String getDisplayName() {
        return DISPLAY_NAME;
    }

    public DynamicFormDescription getFormDescription() {
        return FORM_DESCRIPTION;
    }

    public String getId() {
        return ID;
    }

    public List<MessagingAction> getMessageActions() {
        return Collections.emptyList();
    }

    public static String buildFolderId(int accountId, String folder) {
        StringBuilder stringBuilder = new StringBuilder(ID);
        stringBuilder.append("://").append(accountId).append('/').append(folder);
        return stringBuilder.toString();
    }
}
